Index: kernel/generic/src/ipc/irq.c
===================================================================
--- kernel/generic/src/ipc/irq.c	(revision 0902411958e7833f8eabb379b45b50ca48d95c7e)
+++ kernel/generic/src/ipc/irq.c	(revision 6afc9d780e775e54c1cfb5d3c57fb749979b18d2)
@@ -351,5 +351,5 @@
 		
 		free(irq);
-		return EEXISTS;
+		return EEXIST;
 	}
 	

Index: kernel/generic/src/ipc/event.c
===================================================================
--- kernel/generic/src/ipc/event.c	(revision 0902411958e7833f8eabb379b45b50ca48d95c7e)
+++ kernel/generic/src/ipc/event.c	(revision 6afc9d780e775e54c1cfb5d3c57fb749979b18d2)
@@ -251,5 +251,5 @@
  *
  * @return EOK if the subscription was successful.
  * @return EEXISTS if the notifications of the given type are
  *         already subscribed.
  *
@@ -269,5 +269,5 @@
 		res = EOK;
 	} else
-		res = EEXISTS;
+		res = EEXIST;
 	
 	spinlock_unlock(&event->lock);
@@ -282,5 +282,5 @@
  *
  * @return EOK if the subscription was successful.
  * @return EEXISTS if the notifications of the given type are
  *         already subscribed.
  *
@@ -334,5 +334,5 @@
  * @return EOK on success.
  * @return ELIMIT on unknown event type.
  * @return EEXISTS if the notifications of the given type are
  *         already subscribed.
  *
@@ -251,5 +251,5 @@
  *
  * @return EOK if the subscription was successful.
- * @return EEXISTS if the notifications of the given type are
+ * @return EEXIST if the notifications of the given type are
  *         already subscribed.
  *
@@ -282,5 +282,5 @@
  *
  * @return EOK if the subscription was successful.
- * @return EEXISTS if the notifications of the given type are
+ * @return EEXIST if the notifications of the given type are
  *         already subscribed.
  *
@@ -334,5 +334,5 @@
  * @return EOK on success.
  * @return ELIMIT on unknown event type.
- * @return EEXISTS if the notifications of the given type are
+ * @return EEXIST if the notifications of the given type are
  *         already subscribed.
  *